% Parameters available:

global Rp = 0.15;                         % physical coil radius
global Sp = 0.08;                         % physical coil spacing
global Ip = 100000;                       % physical coil current

global A = 0.15;                          % desired wiffleball radius

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
inv_f = (A^2)/(Rp^2 + (Rp + Sp/sqrt(2))^2);  % spherical inversion factor
global Ri = Rp * inv_f ;                  % image coil radius
global Si = Sp * inv_f ;                  % image coil spacing
global Ii = -Ip / sqrt(inv_f);            % image coil current

global rr = Rp + Sp / sqrt(2);
global clen = 2 * pi * Rp;                % coil length

% calculate field from a polywell, with the top coil missing
function [B] = polywell_5coils(radius, spacing, current, pos)
  rr = radius + spacing / sqrt(2);
  B = loop_bfield3d([-rr,   0,    0], [ 1,   0,    0], radius, current, pos) + \
      loop_bfield3d([ rr,   0,    0], [-1,   0,    0], radius, current, pos) + \
      loop_bfield3d([  0, -rr,    0], [ 0,   1,    0], radius, current, pos) + \
      loop_bfield3d([  0,  rr,    0], [ 0,  -1,    0], radius, current, pos) + \
      loop_bfield3d([  0,   0,  -rr], [ 0,   0,    1], radius, current, pos);
endfunction

function y = force_z(x)
  global rr clen Rp Sp Ip Ri Si Ii dowb
  angle = (x / clen) * 2 * pi;
  pos = [ Rp * cos(angle), Rp * sin(angle), rr];
  L = -[ -sin(angle), cos(angle), 0 ];
  B = polywell_5coils(Rp, Sp, Ip, pos);
  % and add the image coils
  if dowb
    B = B .+ polywell_bfield (Ri, Si, Ii, pos);
  endif
  F = Ip .* cross(L,B);
  y = F(3); % take the z component
endfunction

% quad: Gaussian quadrature, over the length of the coil
printf ("Radius: %.2f m, spacing %.2f m, current %.2f A\n", Rp, Sp, Ip);
printf ("Wiffleball radius: %.2f m\n", A);
global dowb = false;
printf ("NO WB: Force pushing the top coil away is %.2f N\n", quad(@force_z,0,clen));
dowb = true;
printf ("W/ WB: Force pushing the top coil away is %.2f N\n", quad(@force_z,0,clen));

